@@ -1,5 +1,5 @@
 /*
-uptimed - Copyright (c) 1998-2000 Rob Kaper <cap@capsi.com>
+uptimed - Copyright (c) 1998-2004 Rob Kaper <rob@unixcode.org>
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -25,7 +25,7 @@ uptimed - Copyright (c) 1998-2000 Rob Kaper <cap@capsi.com>
 Urec	*u_current;
 time_t	first, prev;
 int		runas_cgi=0, show_max=10, show_milestone=0, layout=PRE, run_loop=0, update_interval=5;
-int		no_ansi=0, no_stats=0, no_current=0;
+int		sort_by=0, no_ansi=0, no_stats=0, no_current=0;
 
 int main(int argc, char *argv[])
 {
@@ -125,7 +125,7 @@ void displayrecords(int cls)
 		printf("<th>%s</th>\n", "Boot up");
 	}
 
-	for (u=urec_list;u;u=u->next)
+	for ( u=sort_urec(urec_list, sort_by) ; u ; u=u->next )
 	{
 		if (++i<=show_max || show_max==0)
 		{
@@ -332,7 +332,7 @@ void scan_args(int argc, char *argv[])
 {
 	int i;
 
-	while((i = getopt(argc, argv, "i:m:?acfsMv")) != EOF)
+	while((i = getopt(argc, argv, "i:m:?acbBkKfsMv")) != EOF)
 	{
 		switch(i)
 		{
@@ -342,6 +342,22 @@ void scan_args(int argc, char *argv[])
 				case 'a':
 						no_ansi++;
 						break;
+				case 'b':
+						sort_by = 1;
+						no_stats++;
+						break;
+				case 'B':
+						sort_by = -1;
+						no_stats++;
+						break;
+				case 'k':
+						sort_by = 2;
+						no_stats++;
+						break;
+				case 'K':
+						sort_by = -2;
+						no_stats++;
+						break;
 				case 'c':
 						no_current++;
 						break;
@@ -391,6 +407,10 @@ void print_help(char *argv[])
 	printf("usage: %s [OPTION]...\n\n", argv[0]);
 	printf("  -?             this help\n");
 	printf("  -a             do not print ansi codes\n");
+	printf("  -b             sort by boottime\n");
+	printf("  -B             reverse sort by boottime\n");
+	printf("  -k             sort by sysinfo\n");
+	printf("  -K             reverse sort by sysinfo\n");
 	printf("  -c             do not show current entry if not in top entries\n");
 	printf("  -f             run continously in a loop\n");
 	printf("  -s             do not print extra statistics\n");
