@@ -1,5 +1,5 @@
 /*
-uptimed - Copyright (c) 1998-2002 Rob Kaper <cap@capsi.com>
+uptimed - Copyright (c) 1998-2004 Rob Kaper <rob@unixcode.org>
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -394,7 +394,7 @@ void print_help(char *argv[])
 
 void print_version(void)
 {
-	printf("uptimed " VERSION " by Rob Kaper <cap@capsi.com>\n");
+	printf("uptimed " VERSION " by Rob Kaper <rob@unixcode.org>\n");
 	exit(0);
 }
 
@@ -433,7 +433,7 @@ void mail(Milestone *milestone, int position)
 		str[sizeof(str)-1] = 0;
 	}
 
-	strncat(str, "\nCongratulations!\n\nUptimed author,\nRob Kaper <cap@capsi.com>\n-- \nThis message was automatically generated by Uptimed.\nUptimed e-mail notifications can be configured from the uptimed.conf file.\nFor more information visit <http://cx.capsi.com/code-uptimed.html>.\n", sizeof(str)-1);
+	strncat(str, "\nCongratulations!\n\nUptimed author,\nRob Kaper <rob@unixcode.org>\n-- \nThis message was automatically generated by Uptimed.\nUptimed e-mail notifications can be configured from the uptimed.conf file.\nFor more information visit <http://cx.capsi.com/code-uptimed.html>.\n", sizeof(str)-1);
 	str[sizeof(str)-1] = 0;
 	
 	snprintf(cmd, sizeof(cmd)-1, "printf \"%s\" | %s", str, sendmail);	
